@@ -90,7 +90,7 @@ class AuthHelper:
 
         @app.route('/login', methods=['GET'])
         def login():  # pylint: disable=unused-variable
-            return auth0.authorize_redirect(redirect_uri=url_for('callback'))
+            return auth0.authorize_redirect(redirect_uri=url_for('callback', _external=True))
 
         @app.route('/logout', methods=['GET'])
         def logout():  # pylint: disable=unused-variable
