@@ -148,7 +148,7 @@ def test_login_route(mock_app_with_client, mock_oauth, mocker):
     mock_oauth.return_value.register.return_value.authorize_redirect.return_value = ('ok', 200)
     with mock_app_with_client.test_client() as c:
         c.get('/login')
-        mock_url_for.assert_called_once_with('callback')
+        mock_url_for.assert_called_once_with('callback', _external=True)
         mock_oauth.return_value.register.return_value.authorize_redirect.assert_called_once_with(
             redirect_uri=mock_url_for.return_value
         )
